intelmq.bots.experts.ripencc_abuse_contact package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.ripencc_abuse_contact package

## Submodules

## intelmq.bots.experts.ripencc_abuse_contact.expert module

`intelmq.bots.experts.ripencc_abuse_contact.expert.` `BOT`

  alias of `intelmq.bots.experts.ripencc_abuse_contact.expert.RIPENCCExpertDeprecatedBot`

class `intelmq.bots.experts.ripencc_abuse_contact.expert.` `RIPENCCExpertDeprecatedBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.experts.ripe.expert.RIPEExpertBot`

  `init`()

## Module contents